#!/bin/sh
# Copyright (c) 2018-2023 LG Electronics, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0

# PmLog
PmLogCtl def surface-manager > /dev/null 2>&1
# pmlog(<level>, <message>)
pmlog() {
    if [ ! -z "$1" -a ! -z "$2" ]; then
        PmLogCtl logkv surface-manager "$1" LSM "category=\"startup\"" "$2" > /dev/null 2>&1
    fi
}

# Default environments that can be overriden
export QT_IM_MODULE=none
export WEBOS_COMPOSITOR_PLUGIN=
export WEBOS_COMPOSITOR_EXTENSIONS=
export WEBOS_COMPOSITOR_PLATFORM=eglfs
export WEBOS_CURSOR_HIDE=0
export WEBOS_CURSOR_TIMEOUT=0
export WEBOS_COMPOSITOR_DISPLAYS=1
export WEBOS_COMPOSITOR_PRIMARY_SCREEN=
export WEBOS_COMPOSITOR_DISPLAY_CONFIG=

# Compositor geometry
export WEBOS_COMPOSITOR_GEOMETRY=$(luna-send -n 1 -a com.webos.surfacemanager luna://com.webos.service.config/getConfigs '{"configNames":["com.webos.surfacemanager.compositorGeometry"]}' | grep -oE "[0-9]+x[0-9]+[\+\-][0-9]+[\+\-][0-9]+r[0-9]+s[0-9]+\.?[0-9]*" || echo "1920x1080+0+0r0s1")

# Import product specific environment variables
PRODUCT_ENVIRONMENT=/etc/surface-manager.d/product.env
if [ -f ${PRODUCT_ENVIRONMENT} ]; then
    pmlog info "Processing ${PRODUCT_ENVIRONMENT} for product specific environment variables."
    source ${PRODUCT_ENVIRONMENT}
else
    pmlog warning "Missing ${PRODUCT_ENVIRONMENT}. Use default values."
fi

pmlog info "Starting /usr/bin/surface-manager with flags -platform ${WEBOS_COMPOSITOR_PLATFORM} ..."
exec /usr/bin/surface-manager -platform ${WEBOS_COMPOSITOR_PLATFORM}
